@@ -106,7 +106,7 @@ void  bonobo_control_frame_sync_realize   (BonoboControlFrame *frame);
 void  bonobo_control_frame_sync_unrealize (BonoboControlFrame *frame);
 
 /* Or this.  It exists just so that BonoboSocket can use it. */
-gboolean bonobo_control_frame_focus (BonoboControlFrame *frame, GtkDirectionType direction);
+gboolean bonobo_control_frame_focus_child (BonoboControlFrame *frame, GtkDirectionType direction);
     
 END_GNOME_DECLS
 
