@@ -197,15 +197,19 @@ bonobo_event_source_notify_listeners (BonoboEventSource *event_source,
 	for (l = event_source->priv->listeners; l; l = l->next) {
 		ListenerDesc *desc = (ListenerDesc *) l->data;
 
-		if (desc->event_masks == NULL || 
-		    event_match (event_name, desc->event_masks))
+		if (desc->event_masks == NULL ||
+		    event_match (event_name, desc->event_masks)) {
+			CORBA_Object_duplicate (desc->listener, my_ev);
 			notify = g_slist_prepend (notify, desc->listener);
+		}
 	}
 
 	bonobo_object_ref (BONOBO_OBJECT (event_source));
 
-	for (l = notify; l; l = l->next)
+	for (l = notify; l; l = l->next) {
 		Bonobo_Listener_event (l->data, event_name, value, my_ev);
+		CORBA_Object_release (l->data, my_ev);
+	}
 
 	bonobo_object_unref (BONOBO_OBJECT (event_source));
 
