@@ -7,7 +7,8 @@
  *	Michael Meeks    (michael@helixcode.com)
  *	Ettore Perazzoli (ettore@helixcode.com)
  */
-#include "bonobo.h"
+#include <bonobo/bonobo-moniker-util.h>
+#include <bonobo/bonobo-exception.h>
 #include <liboaf/liboaf.h>
 #include <liboaf/oaf-async.h>
 #include <ORBitservices/CosNaming.h>
