@@ -1203,7 +1203,24 @@ bonobo_object_list_unref_all (GList **list)
 void
 bonobo_object_slist_unref_all (GSList **list)
 {
-	g_warning ("Dummy - cut and paste above");
+	GSList *l;
+	GSList *unrefs = NULL, *u;
+
+	g_return_if_fail (list != NULL);
+
+	for (l = *list; l; l = l->next) {
+		if (l->data && !BONOBO_IS_OBJECT (l->data))
+			g_warning ("Non object in unref list");
+		else if (l->data)
+			unrefs = g_slist_prepend (unrefs, l->data);
+	}
+
+	unref_list (unrefs);
+
+	for (u = unrefs; u; u = u->next)
+		*list = g_slist_remove (*list, u->data);
+
+	g_slist_free (unrefs);
 }
 
 int
