@@ -12,6 +12,15 @@
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-property-bag-client.h>
 
+static CORBA_unsigned_long
+get_kind (CORBA_TypeCode tc)
+{
+	while (tc->kind == CORBA_tk_alias)
+		tc = tc->subtypes [0];
+
+	return tc->kind;
+}
+
 /**
  * bonobo_property_bag_client_get_properties:
  * @pb: A #Bonobo_PropertyBag      which is bound to a remote
@@ -454,7 +463,7 @@ bonobo_property_bag_client_get_field_##type (Bonobo_PropertyBag       pb,	\
 	if (any == NULL)							\
 		return 0.0;							\
 										\
-        if (any->_type->kind != tk) {                                           \
+        if (get_kind (any->_type) != tk) {                                           \
                 g_warning ("Assertion `any->_type->kind == tk' failed");        \
                 CORBA_any__free (any, NULL, TRUE);                              \
                 return (def);                                                   \
@@ -491,7 +500,7 @@ bonobo_property_bag_client_get_field_string (Bonobo_PropertyBag       pb,
 	if (any == NULL)
 		return NULL;
 
-	if (any->_type->kind != CORBA_tk_string) {
+	if (get_kind (any->_type) != CORBA_tk_string) {
 		g_warning ("assertion failed: `any->_type->kind == CORBA_tk_string'");
 		CORBA_any__free (any, NULL, TRUE);
 		return NULL;
@@ -787,7 +796,7 @@ bonobo_property_bag_client_setv (Bonobo_PropertyBag       pb,
 		if (type == TC_null)
 			return g_strdup_printf ("No such arg '%s'", arg_name);
 
-		switch (type->kind) {
+		switch (get_kind (type)) {
 			SEND (pb, arg_name, var_args, _boolean, _gboolean, int);
 			SEND (pb, arg_name, var_args, _long,    _glong,    int);
 			SEND (pb, arg_name, var_args, _float,   _gfloat,   double);
@@ -805,7 +814,7 @@ bonobo_property_bag_client_setv (Bonobo_PropertyBag       pb,
 
 		default:
 			return g_strdup_printf ("Unhandled setv arg '%s' type %d",
-						arg_name, type->kind);
+						arg_name, get_kind (type));
 		}
 
 		arg_name = va_arg (var_args, char *);
@@ -855,7 +864,7 @@ bonobo_property_bag_client_getv (Bonobo_PropertyBag pb,
 		if (type == TC_null)
 			return g_strdup_printf ("No such arg '%s'", arg_name);
 
-		switch (type->kind) {
+		switch (get_kind (type)) {
 
 			RECEIVE (pb, arg_name, var_args, _boolean, _gboolean, int);
 			RECEIVE (pb, arg_name, var_args, _long,    _glong,    int);
@@ -874,7 +883,7 @@ bonobo_property_bag_client_getv (Bonobo_PropertyBag pb,
 
 		default:
 			return g_strdup_printf ("Unhandled getv arg '%s' type %d",
-						arg_name, type->kind);
+						arg_name, get_kind (type));
 		}
 
 		arg_name = va_arg (var_args, char *);
