@@ -2,10 +2,10 @@
  * Some XML-based BonoboPropertyBag persistence helpers.
  *
  * Authors:
- *   Michael Meeks (michael@helixcode.com)
- *   Nat Friedman  (nat@nat.org)
+ *   Michael Meeks  (michael@ximian.com)
+ *   Dietmar Maurer (dietmar@ximian.com)
  *
- * Copyright 1999,2000 Helix Code, Inc.
+ * Copyright 2000 Ximian, Inc.
  */
 #include <config.h>
 #include <stdlib.h>
@@ -66,6 +66,26 @@ ORBit_demarshal_allocate_mem(CORBA_TypeCode tc, gint nelements)
 	return retval;
 }
 
+static void
+encode_type (BonoboUINode      *type_parent,
+	     CORBA_TypeCode     tc,
+	     CORBA_Environment *ev);
+
+static void
+encode_subtypes (BonoboUINode      *parent,
+		 CORBA_TypeCode     tc,
+		 int                num_subtypes,
+		 CORBA_Environment *ev)
+{
+	BonoboUINode *subtypes;
+	int           i;
+
+	subtypes = bonobo_ui_node_new_child (parent, "subtypes");
+
+	for (i = 0; i < num_subtypes; i++)
+		encode_type (subtypes, tc->subtypes [i], ev);
+}
+
 static void
 encode_type (BonoboUINode      *type_parent,
 	     CORBA_TypeCode     tc,
@@ -107,19 +127,16 @@ encode_type (BonoboUINode      *type_parent,
 			bonobo_ui_node_set_content (subname, tc->subnames [i]);
 		}
 	}
-	if (tc->kind == CORBA_tk_enum)
-		break;
+	if (tc->kind != CORBA_tk_enum)
+		encode_subtypes (node, tc, tc->sub_parts, ev);
+	break;
 
 	case CORBA_tk_alias:
 	case CORBA_tk_array:
-	case CORBA_tk_sequence: { /* subtypes */
-		BonoboUINode *subtypes;
+	case CORBA_tk_sequence:
+		encode_subtypes (node, tc, 1, ev);
+		break;
 
-		subtypes = bonobo_ui_node_new_child (node, "subtypes");
-
-		for (i = 0; i < tc->sub_parts; i++)
-			encode_type (subtypes, tc->subtypes [i], ev);
-	}
 	default:
 		break;
 	}
@@ -233,7 +250,6 @@ encode_value (BonoboUINode      *parent,
 		encode_value (node, tc->subtypes [0], value, ev);
 		break;
 
-
 	case CORBA_tk_union:
 	case CORBA_tk_Principal:
 	case CORBA_tk_fixed:
@@ -247,6 +263,23 @@ encode_value (BonoboUINode      *parent,
 		bonobo_ui_node_set_content (node, scratch);
 }
 
+/**
+ * bonobo_property_bag_xml_encode_any:
+ * @opt_parent: optional parent, should be NULL
+ * @any: the Any to serialize
+ * @ev: a corba exception environment
+ * 
+ * This routine encodes @any into an XML tree using the
+ * #BonoboUINode XML abstraction. @ev is used for flagging
+ * any non-fatal exceptions during the process. On exception
+ * NULL will be returned. opt_parent should be NULL, and is
+ * used internally for recursive tree construction.
+ *
+ * Both type and content data are dumped in a non-standard, but
+ * trivial format.
+ * 
+ * Return value: the XML tree representing the Any
+ **/
 BonoboUINode *
 bonobo_property_bag_xml_encode_any (BonoboUINode      *opt_parent,
 				    const CORBA_any   *any,
@@ -270,6 +303,51 @@ bonobo_property_bag_xml_encode_any (BonoboUINode      *opt_parent,
 	return node;
 }
 
+static CORBA_TypeCode
+decode_type (BonoboUINode      *node,
+	     CORBA_Environment *ev);
+
+static gboolean
+decode_subtypes_into (BonoboUINode      *parent,
+		      CORBA_TypeCode     tc,
+		      int                num_subtypes,
+		      CORBA_Environment *ev)
+{
+	BonoboUINode *l, *subtypes = NULL;
+	int           i = 0;
+
+	for (l = bonobo_ui_node_children (parent); l;
+	     l = bonobo_ui_node_next (l)) {
+		if (bonobo_ui_node_has_name (l, "subtypes"))
+			subtypes = l;
+	}
+	if (!subtypes) {
+		g_warning ("Missing subtypes field - leak");
+		return FALSE;
+	}
+
+	tc->subtypes = g_new (CORBA_TypeCode, num_subtypes);
+
+	for (l = bonobo_ui_node_children (subtypes); l;
+	     l = bonobo_ui_node_next (l)) {
+
+		if (i >= num_subtypes)
+			g_warning ("Too many sub types should be %d", num_subtypes);
+		else {
+			tc->subtypes [i] = decode_type (l, ev);
+			g_assert (tc->subtypes [i]);
+		}
+		i++;
+	}
+
+	if (i < num_subtypes) {
+		g_warning ("Not enough sub names: %d should be %d", i, num_subtypes);
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
 static CORBA_TypeCode
 decode_type (BonoboUINode      *node,
 	     CORBA_Environment *ev)
@@ -322,6 +400,8 @@ decode_type (BonoboUINode      *node,
 	ORBit_RootObject_set_interface ((ORBit_RootObject) tc,
 					(ORBit_RootObject_Interface *) &ORBit_TypeCode_epv,
 					NULL);
+	/* set refs to 1 */
+	CORBA_Object_duplicate ((CORBA_Object)tc, NULL);
 
 	if ((txt = bonobo_ui_node_get_attr (node, "name"))) {
 		tc->name = g_strdup (txt);
@@ -360,7 +440,7 @@ decode_type (BonoboUINode      *node,
 		}
 		if (!subnames) {
 			g_warning ("Missing subnames field - leak");
-			return NULL;
+			goto decode_error;
 		}
 
 		tc->subnames = (const char **) g_new (char *, tc->sub_parts);
@@ -377,52 +457,30 @@ decode_type (BonoboUINode      *node,
 		}
 		if (i < tc->sub_parts) {
 			g_warning ("Not enough sub names: %d should be %d", i, tc->sub_parts);
-			return NULL;
+			goto decode_error;
 		}
 	}
-	if (tc->kind == CORBA_tk_enum)
-		break;
+	if (tc->kind != CORBA_tk_enum)
+		if (!decode_subtypes_into (node, tc, tc->sub_parts, ev))
+			goto decode_error;
+	break;
 
 	case CORBA_tk_alias:
 	case CORBA_tk_array:
-	case CORBA_tk_sequence: { /* subtypes */
-		BonoboUINode *subtypes = NULL;
-		int           i = 0;
+	case CORBA_tk_sequence:
+		if (!decode_subtypes_into (node, tc, 1, ev))
+			goto decode_error;
+		break;
 
-		for (l = bonobo_ui_node_children (node); l;
-		     l = bonobo_ui_node_next (l)) {
-			if (bonobo_ui_node_has_name (l, "subtypes"))
-				subtypes = l;
-		}
-		if (!subtypes) {
-			g_warning ("Missing subtypes field - leak");
-			return NULL;
-		}
-
-		tc->subtypes = g_new (CORBA_TypeCode, tc->sub_parts);
-
-		for (l = bonobo_ui_node_children (subtypes); l;
-		     l = bonobo_ui_node_next (l)) {
-
-			if (i >= tc->sub_parts)
-				g_warning ("Too many sub types should be %d", tc->sub_parts);
-			else {
-				tc->subtypes [i] = decode_type (l, ev);
-				g_assert (tc->subtypes [i]);
-			}
-			i++;
-		}
-
-		if (i < tc->sub_parts) {
-			g_warning ("Not enough sub names: %d should be %d", i, tc->sub_parts);
-			return NULL;
-		}
-	}
 	default:
 		break;
 	}
 
 	return tc;
+
+ decode_error:
+	CORBA_Object_release ((CORBA_Object) tc, ev);
+	return NULL;
 }
 
 #define DO_DECODE(tckind,format,corbatype,value,align)				\
@@ -603,6 +661,16 @@ decode_value (BonoboUINode      *node,
 	bonobo_ui_node_free_string (scratch);
 }
 
+/**
+ * bonobo_property_bag_xml_decode_any:
+ * @node: the parsed XML representation of an any
+ * @ev: a corba exception environment
+ * 
+ * This routine is the converse of bonobo_property_bag_xml_encode_any.
+ * It hydrates a serialized CORBA_any.
+ * 
+ * Return value: the CORBA_any or NULL on error
+ **/
 CORBA_any *
 bonobo_property_bag_xml_decode_any (BonoboUINode      *node,
 				    CORBA_Environment *ev)
@@ -635,6 +703,7 @@ bonobo_property_bag_xml_decode_any (BonoboUINode      *node,
 	}
 
 	tc = decode_type (type, ev);
+
 	g_return_val_if_fail (tc != NULL, NULL);
 
 	block_size = ORBit_gather_alloc_info (tc);
@@ -649,7 +718,7 @@ bonobo_property_bag_xml_decode_any (BonoboUINode      *node,
 			(ORBit_free_childvals) ORBit_free_via_TypeCode,
 			GINT_TO_POINTER (1), sizeof(CORBA_TypeCode));
 		*(CORBA_TypeCode *)((char *) retval - sizeof (ORBit_mem_info) -
-				    sizeof (CORBA_TypeCode)) = (CORBA_TypeCode) CORBA_Object_duplicate((CORBA_Object)tc, NULL);
+				    sizeof (CORBA_TypeCode)) = tc;
 	} else
 		retval = NULL;
 
