@@ -16,6 +16,7 @@
 
 #include <gnome-xml/tree.h>
 #include <gnome-xml/parser.h>
+#include <gnome-xml/xmlmemory.h>
 
 static const char write_lut[16] = {
 	'0', '1', '2', '3', '4', '5', '6', '7',
@@ -1053,7 +1054,7 @@ bonobo_ui_util_translate_ui (BonoboUINode *bnode)
 {
         BonoboUINode *l;
         xmlNode *node;
-	xmlAttr *prop, *old_props;
+	xmlAttr *prop;
 
 	if (!bnode)
 		return;
@@ -1065,32 +1066,36 @@ bonobo_ui_util_translate_ui (BonoboUINode *bnode)
 	}
 
 	node = XML_NODE (bnode);
+	for (prop = node->properties; prop; prop = prop->next) {
 
-	old_props = node->properties;
-	node->properties = NULL;
-
-	for (prop = old_props; prop; prop = prop->next) {
-		xmlChar *value;
-
-		value = xmlNodeListGetString (NULL, prop->val, 1);
+		/* FIXME: with more evilness we can make this yet faster */
 
 		/* Find translatable properties */
 		if (prop->name && prop->name [0] == '_') {
 			char *encoded;
-			encoded = bonobo_ui_util_encode_str (_(value));
-			xmlNewProp (node, &prop->name [1], encoded);
-			g_free (encoded);
-		} else
-			xmlNewProp (node, prop->name, value);
+			xmlChar *value;
+			xmlChar *newname;
 
-		if (value)
+			value = xmlNodeListGetString (NULL, prop->val, 1);
+
+			encoded = bonobo_ui_util_encode_str (_(value));
+			if (prop->val)
+				xmlFreeNodeList (prop->val);
+
+			/* We know there are no entities, it's a hex string */
+			prop->val = xmlStringGetNodeList (NULL, encoded);
+			g_free (encoded);
+			
 			bonobo_ui_node_free_string (value);
+
+			newname = xmlStrdup (prop->name + 1);
+			xmlFree ((xmlChar *)prop->name);
+			prop->name = newname;
+		}	
 	}
 
 	for (l = bonobo_ui_node_children (bnode); l; l = bonobo_ui_node_next (l))
 		bonobo_ui_util_translate_ui (l);
-
-	xmlFreePropList (old_props);
 }
 
 /**
@@ -1211,8 +1216,6 @@ bonobo_ui_util_new_ui (BonoboUIComponent *component,
 
         node = bonobo_ui_node_from_file (file_name);
 
-	bonobo_ui_node_strip (&node);
-
 	bonobo_ui_util_translate_ui (node);
 
 	bonobo_ui_util_fixup_help (component, node, app_datadir, app_name);
@@ -1254,7 +1257,7 @@ bonobo_ui_util_set_ui (BonoboUIComponent *component,
 		g_warning ("Can't find '%s' to load ui from", file_name);
 		return;
 	}
-	
+
 	ui = bonobo_ui_util_new_ui (component, fname, app_datadir, app_name);
 	
 	if (ui)
