@@ -9,8 +9,6 @@
  */
 
 #include <config.h>
-#include <gnome.h>
-#include <liboaf/liboaf.h>
 
 #include <bonobo.h>
 
@@ -508,6 +506,6 @@ bonobo_mines_factory (BonoboGenericFactory *this, void *data)
 }
 
 BONOBO_OAF_FACTORY ("OAFIID:Bonobo_Sample_Mines_Factory",
-		    "application-x-mines",
+		    "application-x-mines", VERSION,
 		    bonobo_mines_factory,
 		    NULL)
