@@ -21,16 +21,17 @@
 
 #include "properties.h"
 
-Bonobo_PropertyBag pb = CORBA_OBJECT_NIL;
-
-static void
+static gboolean
 populate_property_list (BonoboControlFrame *cf, GtkCList *clist)
 {
 	GList *property_list, *l;
+	Bonobo_PropertyBag pb;
+
+	pb = bonobo_control_frame_get_control_property_bag (cf, NULL);
 
 	/* Get the list of properties. */
 	if (pb == CORBA_OBJECT_NIL) 
-		pb = bonobo_control_frame_get_control_property_bag (cf, NULL);
+		return FALSE;
 
 	property_list = bonobo_property_bag_client_get_property_names (pb, NULL);
 	for (l = property_list; l != NULL; l = l->next) {
@@ -72,6 +73,8 @@ populate_property_list (BonoboControlFrame *cf, GtkCList *clist)
 		gtk_clist_append (clist, row_array);
 	}
 	g_list_free (property_list);
+
+	return TRUE;
 }
 
 static void
@@ -81,6 +84,10 @@ edit_property (GtkCList *clist, GdkEventButton *event, BonoboControlFrame *cf)
 	gint row, col;
 	GList *l;
 	CORBA_TypeCode tc;
+	Bonobo_PropertyBag pb;
+
+	pb = bonobo_control_frame_get_control_property_bag (cf, NULL);
+	g_return_if_fail (pb != CORBA_OBJECT_NIL);
 
 	if (event->button == 3) {
 		gtk_clist_get_selection_info (clist, event->x, event->y,
@@ -138,14 +145,20 @@ show_property_dialog (BonoboControlFrame *cf)
     GtkWidget *dialog;
     GtkWidget *clist;
 
-    dialog = gnome_dialog_new ("Properties", GNOME_STOCK_BUTTON_OK, NULL);
-
     clist = create_proplist (cf);
 
-    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox),
-			clist, TRUE, TRUE, 0);
-
-    gtk_widget_show (clist);
+    if (!clist || !cf) {
+	    dialog = gnome_message_box_new (
+		    _("Component has no editable properties"),
+		    GNOME_MESSAGE_BOX_INFO, GNOME_STOCK_BUTTON_OK, NULL);
+    } else {
+	    dialog = gnome_dialog_new ("Properties", GNOME_STOCK_BUTTON_OK, NULL);
+	    
+	    gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (dialog)->vbox),
+				clist, TRUE, TRUE, 0);
+	    
+	    gtk_widget_show (clist);
+    }
 
     gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
 }
