@@ -378,7 +378,7 @@ ib1_node_open (EFSNode **node, EFSDir *efs_dir, const char *path,
 
 	if (!(*p)) { /* dup directory*/
 		if (type == EFS_FILE) return EFS_ERR_NOTFILE; 
-		(IB1Dir *)(*node) = g_new0 (IB1Dir, 1);
+		(*node) = (EFSNode *)g_new0 (IB1Dir, 1);
 		*((IB1Dir *)(*node)) = *((IB1Dir *)parent);
 		ib1_inode_ref (efs, ((IB1Dir *)(*node))->inode);
 		(*node)->mode &= ~(EFS_ROOT);
@@ -400,7 +400,7 @@ ib1_node_open (EFSNode **node, EFSDir *efs_dir, const char *path,
 	
 	if (de->type & EFS_FILE) {
 		if (!(de->type & EFS_FILE)) return EFS_ERR_NOTFILE;
-		(IB1File *)(*node) = g_new0 (IB1File, 1);
+		(*node) = (EFSNode *)g_new0 (IB1File, 1);
 		(*node)->efs = (EFS *)efs;
 		(*node)->mode = (flags&(EFS_RDWR|EFS_APPEND)) | EFS_FILE | 
 			(de->type&EFS_COMP);
@@ -410,7 +410,7 @@ ib1_node_open (EFSNode **node, EFSDir *efs_dir, const char *path,
 
 	if (de->type & EFS_DIR) {
 		if (!(de->type & EFS_DIR)) return EFS_ERR_NOTDIR;
-		(IB1Dir *)(*node) = g_new0 (IB1Dir, 1);
+		(*node) = (EFSNode *)g_new0 (IB1Dir, 1);
 		(*node)->efs = (EFS *)efs; 
 		(*node)->mode = (flags&EFS_RDWR) | EFS_DIR;
 		((IB1Dir *)(*node))->inode = inode;
